@@ -2,8 +2,8 @@
 Unit tests for database queries code.
 
 """
-from dateutil import parser
 from hdx.database import Database
+from hdx.utilities.dateparse import parse_date
 
 from hdx.freshness.emailer.utils.databasequeries import DatabaseQueries
 from hdx.freshness.emailer.utils.hdxhelper import HDXHelper
@@ -11,7 +11,9 @@ from hdx.freshness.emailer.utils.hdxhelper import HDXHelper
 
 class TestDatabaseQueries:
     def test_get_cur_prev_runs(self, configuration, database_failure):
-        now = parser.parse("2017-02-01 19:07:30.333492")
+        now = parse_date(
+            "2017-02-01 19:07:30.333492", include_microseconds=True
+        )
         with Database(**database_failure) as session:
             hdxhelper = HDXHelper(
                 site_url="", users=list(), organizations=list()
@@ -20,17 +22,36 @@ class TestDatabaseQueries:
                 session=session, now=now, hdxhelper=hdxhelper
             )
             assert databasequeries.run_numbers == [
-                (0, parser.parse("2017-02-01 09:07:30.333492"))
+                (
+                    0,
+                    parse_date(
+                        "2017-02-01 09:07:30.333492", include_microseconds=True
+                    ),
+                )
             ]
-            now = parser.parse("2017-02-02 19:07:30.333492")
+            now = parse_date(
+                "2017-02-02 19:07:30.333492", include_microseconds=True
+            )
             databasequeries = DatabaseQueries(
                 session=session, now=now, hdxhelper=hdxhelper
             )
             assert databasequeries.run_numbers == [
-                (1, parser.parse("2017-02-02 09:07:30.333492")),
-                (0, parser.parse("2017-02-01 09:07:30.333492")),
+                (
+                    1,
+                    parse_date(
+                        "2017-02-02 09:07:30.333492", include_microseconds=True
+                    ),
+                ),
+                (
+                    0,
+                    parse_date(
+                        "2017-02-01 09:07:30.333492", include_microseconds=True
+                    ),
+                ),
             ]
-            now = parser.parse("2017-01-31 19:07:30.333492")
+            now = parse_date(
+                "2017-01-31 19:07:30.333492", include_microseconds=True
+            )
             databasequeries = DatabaseQueries(
                 session=session, now=now, hdxhelper=hdxhelper
             )
